@@ -12,13 +12,14 @@ from datetime import timedelta
 from collections import defaultdict
 from pywss.headers import *
 from pywss.statuscode import *
-from pywss.websocket import WebSocketContextWrap
+from pywss.websocket import WebSocketUpgrade, WebSocketContextWrap
+from pywss.testing import HttpTestRequest, HttpTestResponse
 from pywss.static import NewStaticHandler
 from pywss.closing import Closing
 from pywss.routing import Route
 from pywss.openapi import openapi_ui_template, merge_dict, parameters_filter
 
-__version__ = '0.1.4'
+__version__ = '0.1.6'
 
 
 class Context:
@@ -198,10 +199,10 @@ class Context:
         self.set_content_length(os.stat(file.fileno())[6])
         self.response_body.append(file)
 
-    def ws_read(self):
+    def ws_read(self):  # by WebSocketUpgrade
         raise NotImplementedError
 
-    def ws_write(self, body):
+    def ws_write(self, body):  # by WebSocketUpgrade
         raise NotImplementedError
 
     def flush(self):
@@ -322,28 +323,29 @@ class App:
             handlers.append(staticHandler(rootDir))
         if not route.endswith("*"):
             route = f"{route.strip().rstrip('/')}/*"
-        self.register("GET", route, handlers)
+        self.register(MethodGet, route, handlers)
+        self.register(MethodHead, route, handlers)
 
     def get(self, route, *handlers) -> None:
-        self.register("GET", route, handlers)
+        self.register(MethodGet, route, handlers)
 
     def post(self, route, *handlers) -> None:
-        self.register("POST", route, handlers)
+        self.register(MethodPost, route, handlers)
 
     def head(self, route, *handlers) -> None:
-        self.register("HEAD", route, handlers)
+        self.register(MethodHead, route, handlers)
 
     def put(self, route, *handlers) -> None:
-        self.register("PUT", route, handlers)
+        self.register(MethodPut, route, handlers)
 
     def delete(self, route, *handlers) -> None:
-        self.register("DELETE", route, handlers)
+        self.register(MethodDelete, route, handlers)
 
     def patch(self, route, *handlers) -> None:
-        self.register("PATCH", route, handlers)
+        self.register(MethodPatch, route, handlers)
 
     def options(self, route, *handlers) -> None:
-        self.register("OPTIONS", route, handlers)
+        self.register(MethodOptions, route, handlers)
 
     def any(self, route, *handlers) -> None:
         self.get(route, *handlers)
@@ -421,6 +423,8 @@ class App:
             ctx.log = log
             ctx.next()
             ctx.flush()
+        except ConnectionAbortedError:
+            log.error("connect abort")
         except:
             log.traceback()
         finally:
